import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  format,
} from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');

const traits = ["Leaf","Class","SpecimenNumber","Eccentricity","AspectRatio","Elongation","Solidity","StochasticConvexity","IsoperimetricFactor","MaximalIndentationDepth","Lobedness","AverageIntensity","AverageContrast","Smoothness","ThirdMoment","Uniformity","Entropy"];

const render = (data) => {
	cell(data, 5,6)
  cell(data, 6,7)	
  
};
	

const cell = (data, x, y) => {
  
  const xValue = (d) => d[traits[x]];
  const yValue = (d) => d[traits[y]];
  const circleRadius = 5;
  const xAxisLabel = '';
  const yAxisLabel = '';
  const titleLabel = '';
  const margin = {
    top: 50 + (x-6)*200,
    right: 40 - (y-7)*500,
    bottom: 75 - (x-7)*200,
    left: 140 + (y-6)*500,
  };
  /*const margin = {
    top: 50 ,
    right: 40 ,
    bottom: 75 ,
    left: 140 ,
   };*/
  
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;

  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();

  const yScale = scaleLinear()
    .domain([d3.min(data, yValue), d3.max(data, yValue)])
    .range([innerHeight, 0])
    .nice();

  const g = svg
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left}, ${margin.top})`
    
    );

  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);

  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(15);

  const yAxisG = g.append('g').call(yAxis);

  yAxisG.select('.domain').remove();

  const xAxisG = g
    .append('g')
    .call(xAxis)
    .attr('transform', `translate(0, ${innerHeight})`);

  xAxisG.select('.domain').remove();

  g.selectAll('circle')
    .data(data)
    .enter()
    .append('circle')
    .attr('cy', (d) => yScale(yValue(d)))
    .attr('cx', (d) => xScale(xValue(d)))
    .attr('r', circleRadius);

  g.append('text')
    .text(titleLabel)
    .attr('y', -10)
    .attr('class', 'title');

  xAxisG
    .append('text')
    .attr('class', 'axis-label')
    .text(xAxisLabel)
    .attr('fill', 'black')
    .attr('x', innerWidth / 2)
    .attr('y', 60);

  yAxisG
    .append('text')
    .attr('class', 'axis-label')
    .attr('transform', 'rotate(-90)')
    .text(yAxisLabel)
    .attr('fill', 'black')
    .attr('x', -innerWidth / 4)
    .attr('y', -95)
    .attr('text-anchor', 'middle');



};

csv('data.csv').then((data) => {
  /*data.forEach(d => {
  	d.Leaf = +d.Leaf;
  	d.Class = +d.Class;
  	d.SpecimenNumber = +d.SpecimenNumber;
  	d.Eccentricity = +d.Eccentricity;
  	d.AspectRatio = +d.AspectRatio;
  	d.Elongation = +d.Elongation;
  	d.Solidity = +d.Solidity;
  	d.StochasticConvexity = +d.StochasticConvexity;
  	d.IsoperimetricFactor = +d.IsoperimetricFactor;
  	d.MaximalIndentationDepth = +d.MaximalIndentationDepth;
  	d.Lobedness = +d.Lobedness;
  	d.AverageIntensity = +d.AverageIntensity;
  	d.AverageContrast = +d.AverageContrast;
  	d.Smoothness = +d.Smoothness;
    d.ThirdMoment = +d.ThirdMoment;
		d.Uniformity = +d.Uniformity;
		d.Entropy = +d.Entropy;
  });*/
  render(data)
  


  
});


